@@ -1,4 +1,4 @@
-import re
+import re, warnings
 import numpy as np
 
 from enum import Enum
@@ -153,7 +153,7 @@ class GaussianFile(File):
             raise ValueError("can't write a file without a route card")
 
         if not re.match(r"^#p", route_card):
-            print(f"ALERT - route card doesn't start with #p: {route_card}")
+            warnings.warn(f"route card doesn't start with #p: {route_card}")
 
         #### generate the text
         text = ""
@@ -387,10 +387,9 @@ class GaussianFile(File):
                 if len(temperature) == 1:
                     properties[-1]["temperature"] = temperature[0]
                     try:
-                        corrected_free_energy = get_corrected_free_energy(gibbs_vals[0], frequencies,
-                                                                        frequency_cutoff=100.0, temperature=temperature[0])
-                        properties[-1]["quasiharmonic_gibbs_free_energy"] = float(corrected_free_energy)
-                    except:
+                        corrected_free_energy = get_corrected_free_energy(gibbs_vals[0], frequencies, frequency_cutoff=100.0, temperature=temperature[0])
+                        properties[-1]["quasiharmonic_gibbs_free_energy"] = float(f"{float(corrected_free_energy):.6f}") # yes this is dumb
+                    except Exception as e:
                         pass
 
 
@@ -530,20 +529,22 @@ class GaussianFile(File):
         else:
             return f
 
-    def get_molecule(self, num=None):
+    def get_molecule(self, num=None, properties=False):
         """
         Returns the last molecule (from an optimization job) or the only molecule (from other jobs).
 
         If ``num`` is specified, returns ``self.ensemble.molecule_list()[num]``
+        If ``properties`` is True, returns ``(molecule, properties)``.
         """
         # some methods pass num=None, which overrides setting the default above
         if num is None:
             num = -1
+        assert isinstance(num, int), "num must be int"
 
-        if not isinstance(num, int):
-            raise TypeError("num must be int")
-
-        return self.ensemble.molecule_list()[num]
+        if properties:
+            return self.ensemble.molecule_list()[num], self.ensemble.properties_list()[num]
+        else:
+            return self.ensemble.molecule_list()[num]
 
     @classmethod
     def _assign_job_types(cls, header):
