@@ -1,4 +1,4 @@
-import math, copy, re
+import math
 import numpy as np
 
 import cctk
@@ -23,7 +23,8 @@ class VibrationalMode:
         force_constant (float): force constant, in kcal/mol per Å
         reduced_mass (float): mass, in amus
         intensity (float): IR intensity
-        displacements (cctk.OneIndexedArray): displacements
+        displacements (cctk.OneIndexedArray): atom displacements
+        velocities (cctk.OneIndexedArray): atom velocities
 
     """
     def __init__(self, frequency, force_constant, reduced_mass, intensity, displacements):
@@ -97,15 +98,13 @@ class VibrationalMode:
     def random_displacement(self, level=0, method="quasiclassical", max_attempts=1e5):
         """
         Args:
-            method (str): "quasiclassical" for now
+            method (str): "quasiclassical" or "classical"
             level (int): which vibrational level
             max_attempts (int): how many tries you get
 
         Returns:
             shift
         """
-        energy = self.energy(level)
-
         if method == "quasiclassical":
             min_val = 0
             max_val = self.quantum_distribution_max(level)
@@ -123,9 +122,25 @@ class VibrationalMode:
                     attempts += 1
 
             raise ValueError("max_attempts exceeded - can't get a proper initialization for this mode!")
-        else:
-            raise ValueError(f"invalid method {method} - only ``quasiclassical`` implemented currently!")
+        elif method == "classical":
+            min_val = self.classical_distribution_value(0)
+            max_x = self.classical_turning_point()
+            max_val = self.classical_distribution_value(max_x)
 
+            attempts = 0
+            while attempts < max_attempts:
+                x = np.random.uniform(-1*max_x, max_x)
+                p = self.classical_distribution_value(max_x)
+
+                y = np.random.uniform(min_val, max_val)
+                if y < p:
+                    return x
+                else:
+                    attempts += 1
+        else:
+            raise ValueError(f"invalid method {method} - only ``quasiclassical`` and ``classical`` implemented currently!")
+
+        raise ValueError("Max attempts exceeded!")
 
     def quantum_distribution_value(self, x, level=0):
         """
@@ -156,10 +171,6 @@ class VibrationalMode:
         """
         assert isinstance(level, int) and level >= 0, "need positive integer for vibrational level"
 
-        freq = self.frequency
-        if freq < MIN_FREQUENCY:
-            freq = MIN_FREQUENCY
-
         if level == 0:
             return self.quantum_distribution_value(0)
 
@@ -174,8 +185,21 @@ class VibrationalMode:
 
         return max_p
 
+    def classical_distribution_value(self, x, num_pts=1e5):
+        """
+        Returns the value of the classical distribution at the specified ``x`` value.
+        """
+        max_x = self.classical_turning_point()
+        return 1/(math.pi * math.sqrt(max_x**2 - x**2))
+
     def classical_turning_point(self, level=0):
         """
         Returns the maximum allowed shift based on modelling the mode as a classical harmonic oscillator (e.g. the point where potential energy is maximum).
         """
         return math.sqrt(2 * self.energy(level) / self.force_constant)
+
+    def to_string(self):
+        ...
+
+    def from_string(self):
+        ...
