@@ -134,6 +134,9 @@ class TestGaussian(unittest.TestCase):
         file = cctk.GaussianFile.read_file(path)
         ense = file.ensemble
         self.assertEqual(ense[-1, "dipole_moment"], 0.3316)
+        self.assertEqual(ense[-1, "dipole_vector"][0], 0)
+        self.assertEqual(ense[-1, "dipole_vector"][1], 0)
+        self.assertEqual(ense[-1, "dipole_vector"][2], 0.3316)
 
     def test_basis_set_exchange(self):
         path = "test/static/dcm_force.out"
@@ -158,7 +161,25 @@ class TestGaussian(unittest.TestCase):
         path = "test/static/Li.out"
         file = cctk.GaussianFile.read_file(path)
         self.assertTrue(isinstance(file, cctk.GaussianFile))
+        self.assertEqual(file.title, "Title Card Required")
 
+    def test_post_hf(self):
+        path = "test/static/water_mp2.out"
+        file = cctk.GaussianFile.read_file(path)
+        emp2 = file.ensemble[-1,"energy"]
+        self.assertTrue(-76.19037 - emp2 < 0.0001)
+        self.assertEqual(file.title, "title")
+
+        path = "test/static/water_mp4.out"
+        file = cctk.GaussianFile.read_file(path)
+        emp4 = file.ensemble[-1,"energy"]
+        self.assertTrue(-76.20098 - emp4 < 0.0001)
+
+    def test_pathological(self):
+#        path = "test/static/sugar_failed.out"
+#        file = cctk.GaussianFile.read_file(path)
+#        self.assertTrue(isinstance(file, cctk.GaussianFile))
+        pass
 
 if __name__ == '__main__':
     unittest.main()
